==> ejc-profillreport-impl-3.0.0-20240109.025205-30-sources.jar: com/ejianc/business/profillreport/bean/SecurityZgbEntity.java <==
package com.ejianc.business.profillreport.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 直管部安全情况检查统计表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_profillreport_security_zgb")
public class SecurityZgbEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 直管部/分公司id
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 直管部/分公司编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 直管部/分公司
    @TableField(value="project_number")
    private Long projectNumber; // 检查项目（个）
    @TableField(value="general_hazards")
    private Long generalHazards; // 发现一般隐患（条）
    @TableField(value="hazards_rectificat")
    private Long hazardsRectificat; // 已整改（条）
    @TableField(value="hazards_rectificating")
    private Long hazardsRectificating; // 正在整改（条）
    @TableField(value="fjsz_hazards")
    private Long fjszHazards; // 房建、市政项目隐患（条）
    @TableField(value="gl_hazards")
    private Long glHazards; // 公路项目安全隐患（条）
    @TableField(value="slsd_hazards")
    private Long slsdHazards; // 水利水电安全隐患（条）
    @TableField(value="other_hazards")
    private Long otherHazards; // 其他项目安全隐患（条）
    @TableField(value="construction_fire_hazards")
    private Long constructionFireHazards; // 施工现场消防安全隐患（条）
    @TableField(value="construction_car_hazards")
    private Long constructionCarHazards; // 施工现场场内运输车辆安全隐患（条）
    @TableField(value="major_hazards")
    private Long majorHazards; // 重大隐患（条）
    @TableField(value="major_hazards_rectificat")
    private Long majorHazardsRectificat; // 已整改 重大隐患 （条）
    @TableField(value="ajor_hazards_rectificating")
    private Long ajorHazardsRectificating; // 正在整改重大隐患（条）
    @TableField(value="incorrigible_hazards")
    private Long incorrigibleHazards; // 隐患问题屡教不改项（个）
    @TableField(value="notification_documents")
    private Long notificationDocuments; // 发通报文件（份）
    @TableField(value="dispatch_file")
    private Long dispatchFile; // 发给公司层面职能部门工作联系函
    @TableField(value="accountability_zgb")
    private Long accountabilityZgb; // 问责直管部/分公司/项目部管理人员（名）
    @TableField(value="notes")
    private String notes; // 备注
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getProjectNumber() {
        return projectNumber;
    }

    public void setProjectNumber(Long projectNumber) {
        this.projectNumber = projectNumber;
    }
    public Long getGeneralHazards() {
        return generalHazards;
    }

    public void setGeneralHazards(Long generalHazards) {
        this.generalHazards = generalHazards;
    }
    public Long getHazardsRectificat() {
        return hazardsRectificat;
    }

    public void setHazardsRectificat(Long hazardsRectificat) {
        this.hazardsRectificat = hazardsRectificat;
    }
    public Long getHazardsRectificating() {
        return hazardsRectificating;
    }

    public void setHazardsRectificating(Long hazardsRectificating) {
        this.hazardsRectificating = hazardsRectificating;
    }
    public Long getFjszHazards() {
        return fjszHazards;
    }

    public void setFjszHazards(Long fjszHazards) {
        this.fjszHazards = fjszHazards;
    }
    public Long getGlHazards() {
        return glHazards;
    }

    public void setGlHazards(Long glHazards) {
        this.glHazards = glHazards;
    }
    public Long getSlsdHazards() {
        return slsdHazards;
    }

    public void setSlsdHazards(Long slsdHazards) {
        this.slsdHazards = slsdHazards;
    }
    public Long getOtherHazards() {
        return otherHazards;
    }

    public void setOtherHazards(Long otherHazards) {
        this.otherHazards = otherHazards;
    }
    public Long getConstructionFireHazards() {
        return constructionFireHazards;
    }

    public void setConstructionFireHazards(Long constructionFireHazards) {
        this.constructionFireHazards = constructionFireHazards;
    }
    public Long getConstructionCarHazards() {
        return constructionCarHazards;
    }

    public void setConstructionCarHazards(Long constructionCarHazards) {
        this.constructionCarHazards = constructionCarHazards;
    }
    public Long getMajorHazards() {
        return majorHazards;
    }

    public void setMajorHazards(Long majorHazards) {
        this.majorHazards = majorHazards;
    }
    public Long getMajorHazardsRectificat() {
        return majorHazardsRectificat;
    }

    public void setMajorHazardsRectificat(Long majorHazardsRectificat) {
        this.majorHazardsRectificat = majorHazardsRectificat;
    }
    public Long getAjorHazardsRectificating() {
        return ajorHazardsRectificating;
    }

    public void setAjorHazardsRectificating(Long ajorHazardsRectificating) {
        this.ajorHazardsRectificating = ajorHazardsRectificating;
    }
    public Long getIncorrigibleHazards() {
        return incorrigibleHazards;
    }

    public void setIncorrigibleHazards(Long incorrigibleHazards) {
        this.incorrigibleHazards = incorrigibleHazards;
    }
    public Long getNotificationDocuments() {
        return notificationDocuments;
    }

    public void setNotificationDocuments(Long notificationDocuments) {
        this.notificationDocuments = notificationDocuments;
    }
    public Long getDispatchFile() {
        return dispatchFile;
    }

    public void setDispatchFile(Long dispatchFile) {
        this.dispatchFile = dispatchFile;
    }
    public Long getAccountabilityZgb() {
        return accountabilityZgb;
    }

    public void setAccountabilityZgb(Long accountabilityZgb) {
        this.accountabilityZgb = accountabilityZgb;
    }
    public String getNotes() {
        return notes;
    }

    public void setNotes(String notes) {
        this.notes = notes;
    }
    
}

==> ejc-profillreport-impl-3.0.0-20240412.055429-36-sources.jar: com/ejianc/business/profillreport/bean/SecurityZgbEntity.java <==
package com.ejianc.business.profillreport.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 直管部安全情况检查统计表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_profillreport_security_zgb")
public class SecurityZgbEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 直管部/分公司id
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 直管部/分公司编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 直管部/分公司
    @TableField(value="project_number")
    private Long projectNumber; // 检查项目（个）
    @TableField(value="general_hazards")
    private Long generalHazards; // 发现一般隐患（条）
    @TableField(value="hazards_rectificat")
    private Long hazardsRectificat; // 已整改（条）
    @TableField(value="hazards_rectificating")
    private Long hazardsRectificating; // 正在整改（条）
    @TableField(value="fjsz_hazards")
    private Long fjszHazards; // 房建、市政项目隐患（条）
    @TableField(value="gl_hazards")
    private Long glHazards; // 公路项目安全隐患（条）
    @TableField(value="slsd_hazards")
    private Long slsdHazards; // 水利水电安全隐患（条）
    @TableField(value="other_hazards")
    private Long otherHazards; // 其他项目安全隐患（条）
    @TableField(value="construction_fire_hazards")
    private Long constructionFireHazards; // 施工现场消防安全隐患（条）
    @TableField(value="construction_car_hazards")
    private Long constructionCarHazards; // 施工现场场内运输车辆安全隐患（条）
    @TableField(value="major_hazards")
    private Long majorHazards; // 重大隐患（条）
    @TableField(value="major_hazards_rectificat")
    private Long majorHazardsRectificat; // 已整改 重大隐患 （条）
    @TableField(value="ajor_hazards_rectificating")
    private Long ajorHazardsRectificating; // 正在整改重大隐患（条）
    @TableField(value="incorrigible_hazards")
    private Long incorrigibleHazards; // 隐患问题屡教不改项（个）
    @TableField(value="notification_documents")
    private Long notificationDocuments; // 发通报文件（份）
    @TableField(value="dispatch_file")
    private String dispatchFile; // 发给公司层面职能部门工作联系函
    @TableField(value="accountability_zgb")
    private String accountabilityZgb; // 问责直管部/分公司/项目部管理人员（名）
    @TableField(value="notes")
    private String notes; // 备注
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getProjectNumber() {
        return projectNumber;
    }

    public void setProjectNumber(Long projectNumber) {
        this.projectNumber = projectNumber;
    }
    public Long getGeneralHazards() {
        return generalHazards;
    }

    public void setGeneralHazards(Long generalHazards) {
        this.generalHazards = generalHazards;
    }
    public Long getHazardsRectificat() {
        return hazardsRectificat;
    }

    public void setHazardsRectificat(Long hazardsRectificat) {
        this.hazardsRectificat = hazardsRectificat;
    }
    public Long getHazardsRectificating() {
        return hazardsRectificating;
    }

    public void setHazardsRectificating(Long hazardsRectificating) {
        this.hazardsRectificating = hazardsRectificating;
    }
    public Long getFjszHazards() {
        return fjszHazards;
    }

    public void setFjszHazards(Long fjszHazards) {
        this.fjszHazards = fjszHazards;
    }
    public Long getGlHazards() {
        return glHazards;
    }

    public void setGlHazards(Long glHazards) {
        this.glHazards = glHazards;
    }
    public Long getSlsdHazards() {
        return slsdHazards;
    }

    public void setSlsdHazards(Long slsdHazards) {
        this.slsdHazards = slsdHazards;
    }
    public Long getOtherHazards() {
        return otherHazards;
    }

    public void setOtherHazards(Long otherHazards) {
        this.otherHazards = otherHazards;
    }
    public Long getConstructionFireHazards() {
        return constructionFireHazards;
    }

    public void setConstructionFireHazards(Long constructionFireHazards) {
        this.constructionFireHazards = constructionFireHazards;
    }
    public Long getConstructionCarHazards() {
        return constructionCarHazards;
    }

    public void setConstructionCarHazards(Long constructionCarHazards) {
        this.constructionCarHazards = constructionCarHazards;
    }
    public Long getMajorHazards() {
        return majorHazards;
    }

    public void setMajorHazards(Long majorHazards) {
        this.majorHazards = majorHazards;
    }
    public Long getMajorHazardsRectificat() {
        return majorHazardsRectificat;
    }

    public void setMajorHazardsRectificat(Long majorHazardsRectificat) {
        this.majorHazardsRectificat = majorHazardsRectificat;
    }
    public Long getAjorHazardsRectificating() {
        return ajorHazardsRectificating;
    }

    public void setAjorHazardsRectificating(Long ajorHazardsRectificating) {
        this.ajorHazardsRectificating = ajorHazardsRectificating;
    }
    public Long getIncorrigibleHazards() {
        return incorrigibleHazards;
    }

    public void setIncorrigibleHazards(Long incorrigibleHazards) {
        this.incorrigibleHazards = incorrigibleHazards;
    }
    public Long getNotificationDocuments() {
        return notificationDocuments;
    }

    public void setNotificationDocuments(Long notificationDocuments) {
        this.notificationDocuments = notificationDocuments;
    }
    public String getDispatchFile() {
        return dispatchFile;
    }

    public void setDispatchFile(String dispatchFile) {
        this.dispatchFile = dispatchFile;
    }
    public String getAccountabilityZgb() {
        return accountabilityZgb;
    }

    public void setAccountabilityZgb(String accountabilityZgb) {
        this.accountabilityZgb = accountabilityZgb;
    }
    public String getNotes() {
        return notes;
    }

    public void setNotes(String notes) {
        this.notes = notes;
    }
    
}
